@@ -66,7 +66,7 @@ class SpaceProcessor(InlineProcessor):
 class SuppliedProcessor(InlineProcessor):
 
     def handleMatch(self, m, data):
-        el = etree.Element('suppied')
+        el = etree.Element('supplied')
         el.set('reason', 'lost')
         el.text = m.group(1)
         return el, m.start(), m.end()
